Compose

Enum Compose 

#[repr(u8)]
pub enum Compose {
Show 14 variants Clear = 0, Copy = 1, Dest = 2, SrcOver = 3, DestOver = 4, SrcIn = 5, DestIn = 6, SrcOut = 7, DestOut = 8, SrcAtop = 9, DestAtop = 10, Xor = 11, Plus = 12, PlusLighter = 13,
}
Defines the layer composition function for a blend operation.

See W3C’s Compositing and Blending Level 1 draft for more details. Illustrations fall under the W3C open license.

Variants



Clear = 0

No regions are enabled.



Copy = 1

Only the source will be present.



Dest = 2

Only the destination will be present.



SrcOver = 3

The source is placed over the destination.



DestOver = 4

The destination is placed over the source.



SrcIn = 5

The parts of the source that overlap with the destination are placed.



DestIn = 6

The parts of the destination that overlap with the source are placed.



SrcOut = 7

The parts of the source that fall outside of the destination are placed.



DestOut = 8

The parts of the destination that fall outside of the source are placed.



SrcAtop = 9

The parts of the source which overlap the destination replace the destination. The destination is placed everywhere else.



DestAtop = 10

The parts of the destination which overlaps the source replace the source. The source is placed everywhere else.



Xor = 11

The non-overlapping regions of source and destination are combined.



Plus = 12

The sum of the source image and destination image is displayed.



PlusLighter = 13

Allows two elements to cross fade by changing their opacities from 0 to 1 on one element and 1 to 0 on the other element.