Fill

Enum Fill 

#[repr(u8)]
pub enum Fill { NonZero = 0, EvenOdd = 1, }
Describes the rule that determines the interior portion of a shape.

This is only relevant for self-intersecting paths (e.g. an hourglass shape). For non-self-intersecting paths, both rules produce the same result.

Variants



NonZero = 0

Non-zero fill rule.

All regions where the winding number of the path is not zero will be filled. This is generally more correct, but can be more expensive to implement in renderers. This matches the default behavior of the web canvas, and is the default value.



EvenOdd = 1

Even-odd fill rule.

All regions where the winding number of the path is odd will be filled. The most common use case for this rule is as an optimisation when the paths are known not to be self-intersecting. It is also useful for creating intentional holes in self-intersecting shapes (e.g. star or donut-like paths) or to match the SVG/Canvas even-odd fill rule. This can be implemented more efficiently than non-zero, as the winding number state can be stored in only one bit (and so the winding numbers for several pixels can be packed extremely efficiently).